---
title: Upgrade Guides
nav_title: Upgrading
description: Learn how to upgrade to the latest versions of Next.js.
---

Learn how to upgrade to the latest versions of Next.js following the versions-specific guides:
